# ArgoData.jl

Argo data processing and analysis. Currently provides:

- The `GDAC` module functions access and retrieve files from the Argo data servers. 
- `MITprof` supports the format of [Forget, et al 2015](http://dx.doi.org/10.5194/gmd-8-3071-2015) for standard depth data sets like [this one](https://doi.org/10.7910/DVN/EE3C40).
- The `MITprof_plots` module in `examples/`.

_This package is in early developement stage when breaking changes can be expected._

## Workflows

Downloading and accessing an Argo file can simply be done like this.

```
using ArgoData, NCDatasets
(folder,wmo)=("aoml",13857)
file=GDAC.download_file(folder,wmo)
Dataset(file)
```

A list of all `folder,wmo` pairs can be obtained using `files_list=GDAC.files_list()`. And a method to download files in bulk & parallel is presented in [examples/Argo\_distributed\_download.jl](https://github.com/JuliaOcean/ArgoData.jl/blob/master/examples/Argo_distributed_download.jl).

### MITprof Format

Formatting an Argo file (`input_file`) into an MITprof file (`output_file`) proceeds as follows.

```
using ArgoData
gridded_fields=GriddedFields.load()
(input_file,output_file)=("13857_prof.nc","13857_MITprof.nc")
meta=ArgoTools.meta(input_file,output_file)
MITprof.format(meta,gridded_fields,input_file,output_file)
```

The file generated by the previous command can be accessed normally as a NetCDF file (e.g., `Dataset(output_file)`) or using the convenient `MITprofStandard` data structure.

```
using ArgoData
mp=MITprofStandard(output_file)
```

For additional detail, please refer to the [examples/ArgoToMITprof.jl](https://github.com/JuliaOcean/ArgoData.jl/blob/master/examples/ArgoToMITprof.jl) example.

### Download MITprof files

The original collection of MITprof files from [Forget, et al 2015](http://dx.doi.org/10.5194/gmd-8-3071-2015) is archived [here](https://doi.org/10.7910/DVN/EE3C40). These files can be retrieved as follows.

```
fil = "MITprof_mar2016_argo9506.nc"
tmp = CSV.File("examples/dataverse_files.csv") |> DataFrame
ii = findall(tmp[:,:name].==fil)

url0="https://dataverse.harvard.edu/api/access/datafile/"
run(`wget --content-disposition $(url0)$(tmp[ii,:ID])`)
```

## Functions

```@index
```

```@docs
ProfileNative
ProfileStandard
MITprofStandard
```

```@autodocs
Modules = [GDAC,MITprof]
Order   = [:type,:function]
```

